#!/usr/bin/env python

import getpass
import os

try:
    from config import saas_config
except ImportError:
    from .config import saas_config


USER = getpass.getuser()
PG_USER = 'root'
PG_PASS = saas_config['config'].get('pg_pass', 'root')
PG_ODOO_USER = 'odoo'
PG_ODOO_PASS = saas_config['config'].get('pg_odoo_pass', 'odoo')
METABASE_PG_HOST = saas_config['config'].get('metabase_pg_host', 'localhost')
PG_REP_USER = 'replicant'
PG_REP_PASS = 'eratEwUlCijMiptedsAsUdKetphoick6'

# prod
TEST = saas_config['config']['test']
ENV = saas_config['config']['env']
LOCAL = False
MASTER = "https://master.odoo.com"
SAAS_OPS_URL = "https://saas-ops.odoo.com"
SAAS_BASE_URL = 'odoo.com'
SAAS_VALID_SUFFIXES = ('.' + SAAS_BASE_URL, '.my.openerp.com')
PAAS_DOMAINS = ['odoo.com', 'dev.odoo.com']

DOMAIN_SRV = 'v7.openerp.com'
SCHEME = 'https'
WEBSITE = 'https://www.odoo.com'
OAUTH_BASE_URL = 'https://accounts.odoo.com'
# GLOBAL_OAUTH_BASE_URL must not be modifed for test!
GLOBAL_OAUTH_BASE_URL = OAUTH_BASE_URL
BUYAPPS_HOST = 'https://www.odoo.com'
APPS_URL = 'https://apps.odoo.com'
APPS_KEY = saas_config['apps']['apps_key']
APPS_FEE = 0.3
UPGRADE = 'https://upgrade.odoo.com'
UPGRADE_SAAS_KEY = 'tobetokaga'
UPGRADE_KEYSALT = 'bananabananabanana'
UPGRADE_LOCATION = 'eu1'
ODOO_SH_MASTER_URL = 'https://www.odoo.sh'
DNS_MAX_LENGTH = 50
IOT_DOMAIN = 'odoo-iot.com'

IAP_URL = 'https://iap.odoo.com'
BUY_IAP_URL = 'https://www.odoo.com'
IAP_FEE = 0.25

MERGEBOT_URL = 'https://mergebot.odoo.com'
UPGRADECI_URL = 'https://upgradeci.odoo.com'

TIMEOUT = 15
NIGHTLY_SECRET = b'TekvovbetGingyitEyldEshJehuithia'

BRANCH_ALIASES = {
    'master': 9999,
    '7.0': 0,
    '8.0': 5.5,     # between saas-5 and saas-6
    '9.0': 6.5,     # between saas-6 and saas-7
    '10.0': 13.5,   # between saas-13 and saas-14
    '11.0': 18.5,
}

# namespaced directories for transient files
TMPDIR = os.path.expanduser('~/tmp/')
TMPMIGDIR = os.path.join(TMPDIR, 'mig')
TMPMIGSTATICDIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'static', 'mig')
TMPDUMPDIR = os.path.join(TMPDIR, 'dump')
TMPRESTOREDIR = os.path.join(TMPDIR, 'restore')
TMPFROZENDIR = os.path.join(TMPDIR, 'frozen')
TMPDIRS = (TMPMIGDIR, TMPFROZENDIR, TMPRESTOREDIR)

# Extra apps that either do not have the 'application' flag in their manifest but that are
# paying nonetheless (e.g. delivery carriers) OR that used to have the flag in an earlier
# version but not anymore in our production database (e.g. account_voucher)
EXTRA_APPS = ['delivery_dhl', 'delivery_ups', 'delivery_usps',
              'delivery_fedex', 'delivery_temando', 'sale_ebay', 'crm_voip',
              'hr_timesheet_sheet', 'account_voucher', 'sale_amazon']
ONE_APP_FREE_EXCLUDE = [
    'delivery_dhl', 'delivery_ups',
    'delivery_usps', 'delivery_fedex', 'delivery_temando',
    'sale_ebay', 'crm_voip', 'voip', 'delivery_bpost',
    'delivery_easypost', 'sale_amazon',
]

# list of app that cannot be installed for free if more than one - best-effort to avoid extra request on Odoo.com
ONE_APP_FREE_CUMUL_EXCLUDE = [
    'account_consolidation', 'appointment', 'approvals', 'crm', 'helpdesk', 'hr_appraisal',  # 'documents'
    'hr_expense', 'hr_holidays', 'hr_referral', 'industry_fsm', 'marketing_automation', 'mrp_plm',
    'planning', 'point_of_sale', 'purchase', 'quality_control', 'sale_renting', 'sale_subscription',
    'sign', 'voip', 'web_studio', 'website_event', 'website_sale', 'website_slides']
EDU_PREFIX = 'edu-'
SPECIAL_PREFIXES = (EDU_PREFIX, 'pstest-', 'demo-')

# Versions deprecation dates
EDU_EOL_DATES = {
    '13.0': '2024-10-01',
    '14.0': '2024-10-01',
    '15.0': '2024-10-01',
}

GITHUB_ORG = "odoo"
GITHUB_REPO = "enterprise"
GITHUB_TOKEN = saas_config.get('accounts', {}).get('github_collaborators_token', '')  # robodoo
# For each org, if team is set, when setting a github login to an employee, the login should be added to these teams.
# When disabling an employee, his login must be removed from all organizations, whether or not they have a team configured.
GITHUB_STAFF_ORGS = [
    {
        'name': 'odoo',
        'app_id': 48373,
        'installation_id': 5572526,
        'pem_file': os.path.join(os.path.expanduser('~/.ssh'), 'fluffy_odoo_private_key.pem'),
        'team': 'odoo-staff',
    },
    {
        'name': 'odoo-dev',
        'app_id': 48374,
        'installation_id': 5572529,
        'pem_file': os.path.join(os.path.expanduser('~/.ssh'), 'fluffy_odoo_dev_private_key.pem'),
        'team': 'odoo-staff',
    },
    {
        'name': 'odoo-ps',
        'app_id': 48375,
        'installation_id': 5572533,
        'pem_file': os.path.join(os.path.expanduser('~/.ssh'), 'fluffy_odoo_ps_private_key.pem'),
    },
    {
        'name': 'odoo-cna',
        'app_id': 48378,
        'installation_id': 5572664,
        'pem_file': os.path.join(os.path.expanduser('~/.ssh'), 'fluffy_odoo_cna_private_key.pem'),
    },
]

GANDI_API_KEY = saas_config.get('accounts', {}).get('gandi_api_key', '')
GANDI_ODOO_EMPLOYEE_ID = saas_config.get('accounts', {}).get('gandi_odoo_employee_id', '')
GANDI_ORG_ID = saas_config.get('accounts', {}).get('gandi_org_id', '')

IAP_WS_TOKEN = saas_config.get('accounts', {}).get('iap_ws_token', '')
IAP_WS_URL = "https://iap-scraper.odoo.com"

OVH_INVOICING_AK = saas_config.get('accounts', {}).get('ovh_invoicing_ak', '')
OVH_INVOICING_AS = saas_config.get('accounts', {}).get('ovh_invoicing_as', '')
OVH_INVOICING_CK = saas_config.get('accounts', {}).get('ovh_invoicing_ck', '')

DROP_DB_PREFIX = "__drop_"

PLAUSIBLE_SAAS_SERVER = "https://saas-analytics.odoo.com"
PLAUSIBLE_SAAS_SCRIPT = "https://download.odoo.com/js/plausi_saas.js"
PLAUSIBLE_SAAS_APIKEY = saas_config.get('trial', {}).get('plausible_api_key', '')
SIGNED_PARAMS_SHARED_SECRET = saas_config['config']['signed_params_shared_secret'].encode()

EMAIL_DAILY_LIMIT_MASS_MAIL = 20

ABUSE_ALIAS = 'abusee52378f5e373f4cd3140a9f254190117'
ABUSE_URLSCAN_APIKEY = saas_config.get('config', {}).get('abuse_urlscan_apikey', '')

WHATSAPP_TRIAL_PHONE_UID = saas_config.get('trial', {}).get('whatsapp_phone_uid', '')
WHATSAPP_TRIAL_TOKEN = saas_config.get('trial', {}).get('whatsapp_token', '')
PRODUCT_BARCODELOOKUP_APIKEY = saas_config.get('trial', {}).get('barcode_lookup_api_key', '')

# test
if ENV in ('test', 'next') and TEST:
    MASTER = "https://master.%s.odoo.com" % ENV
    SAAS_OPS_URL = "https://saas-ops.test.odoo.com"
    SAAS_BASE_URL = ENV + '.odoo.com'
    SAAS_VALID_SUFFIXES = ('.' + SAAS_BASE_URL,)
    PAAS_DOMAINS = ['test.odoo.com', 'test.odoo.sh']
    DOMAIN_SRV = ENV + '.odoo.com'
    WEBSITE = 'https://www.%s.odoo.com' % ENV
    OAUTH_BASE_URL = 'https://accounts.%s.odoo.com' % ENV
    BUYAPPS_HOST = 'https://www.%s.odoo.com' % ENV
    APPS_URL = 'https://apps.%s.odoo.com' % ENV
    APPS_KEY_PREV = 'PIA_%s_%s_LOE_475cd5b15de7'
    APPS_KEY = 'LOE_%s_%s_%s_PIA_3f60797'
    IAP_URL = 'https://iap.%s.odoo.com' % ENV
    BUY_IAP_URL = 'https://www.%s.odoo.com' % ENV
    UPGRADE = 'https://test.upgrade.odoo.com'
    ODOO_SH_MASTER_URL = 'https://www.test.odoo.sh'
    GITHUB_REPO = ''
    GITHUB_ORG = ''
    GITHUB_TOKEN = ''
    GITHUB_STAFF_ORGS = []
    MERGEBOT_URL = ''
    UPGRADECI_URL = ''

# localdev
elif TEST:
    PG_USER = USER
    PG_PASS = None
    TEST = True
    LOCAL = ENV != 'docker'
    if LOCAL:
        DOMAIN_SRV = 'v7.127.0.0.1.nip.io'
        MASTER = "http://www.127.0.0.1.nip.io:8069"
        SAAS_BASE_URL = 'my.127.0.0.1.nip.io:8269'
    else:
        DOMAIN_SRV = saas_config['config'].get('domain_srv', 'vcap.me')
        SAAS_BASE_URL = 'my.' + DOMAIN_SRV
        MASTER = "http://master." + DOMAIN_SRV
        SAAS_OPS_URL = "http://ops." + DOMAIN_SRV
    SAAS_VALID_SUFFIXES = ('.' + SAAS_BASE_URL.split(':')[0],)
    PAAS_DOMAINS = ['odoo.com.test', 'dev.odoo.com.test']
    SCHEME = 'http'
    if LOCAL:
        WEBSITE = 'http://www.127.0.0.1.nip.io:8369'
        OAUTH_BASE_URL = 'http://accounts.127.0.0.1.nip.io:8369'
        BUYAPPS_HOST = 'http://accounts.127.0.0.1.nip.io:8369'
    else:
        WEBSITE = 'http://www.' + DOMAIN_SRV
        OAUTH_BASE_URL = 'http://accounts.' + DOMAIN_SRV
        BUYAPPS_HOST = 'http://accounts.' + DOMAIN_SRV
        GLOBAL_OAUTH_BASE_URL = OAUTH_BASE_URL
    if LOCAL:
        APPS_URL = 'http://apps.127.0.0.1.nip.io:8069'
    else:
        APPS_URL = 'http://apps.' + DOMAIN_SRV
    IAP_URL = 'http://iap.127.0.0.1.nip.io:8569'
    if LOCAL:
        BUY_IAP_URL = 'http://accounts.127.0.0.1.nip.io:8369'
    else:
        BUY_IAP_URL = 'http://accounts.' + DOMAIN_SRV
    UPGRADE = 'https://test.upgrade.odoo.com'
    ODOO_SH_MASTER_URL = 'https://www.test.odoo.sh'
    GITHUB_REPO = ''
    GITHUB_ORG = ''
    GITHUB_TOKEN = ''
    GITHUB_STAFF_ORGS = []
    MERGEBOT_URL = ''
    UPGRADECI_URL = ''

if __name__ == '__main__':
    import pprint
    pprint.pprint({k: v for k, v in locals().items() if k.isupper()})
